/*
 * Copyright 2014 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.internal.tasks.compile.incremental.jar;

import com.google.common.hash.HashCode;
import org.gradle.api.internal.tasks.compile.incremental.deps.ClassSetAnalysisData;

import java.util.Map;

public class JarSnapshotData {

    final Map<String, HashCode> hashes;
    final ClassSetAnalysisData data;
    final HashCode hash;

    /**
     * @param hash of this jar
     * @param hashes hashes of all classes from the jar
     * @param data of classes analysis in this jar
     */
    public JarSnapshotData(HashCode hash, Map<String, HashCode> hashes, ClassSetAnalysisData data) {
        assert hash != null;
        assert hashes != null;
        assert data != null;

        this.hash = hash;
        this.hashes = hashes;
        this.data = data;
    }
}
